=======
Astropy
=======

.. image:: https://img.shields.io/pypi/v/astropy.svg
    :target: https://pypi.python.org/pypi/astropy

.. image:: https://img.shields.io/pypi/dm/astropy.svg
    :target: https://pypi.python.org/pypi/astropy

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/astropy/astropy 

Astropy (http://astropy.org/) is a package intended to contain much of
the core functionality and some common tools needed for performing
astronomy and astrophysics with Python.

Releases are `registered on PyPI <http://pypi.python.org/pypi/astropy>`_,
and development is occurring at the
`project's github page <http://github.com/astropy/astropy>`_.

For installation instructions, see the `online documentation <http://docs.astropy.org/>`_
or  ``docs/install.rst`` in this source distribution.

For system packagers: Please install Astropy with the command::

    $ python setup.py --offline install

This will prevent the astropy_helpers bootstrap script from attempting to
reach out to PyPI.

Project Status
--------------

.. image:: https://travis-ci.org/astropy/astropy.svg
    :target: https://travis-ci.org/astropy/astropy

.. image:: https://coveralls.io/repos/astropy/astropy/badge.svg
    :target: https://coveralls.io/r/astropy/astropy

.. image:: https://ci.appveyor.com/api/projects/status/ym7lxajcs5qwm31e/branch/master?svg=true
    :target: https://ci.appveyor.com/project/Astropy/astropy/branch/master

For an overview of the testing and build status of all packages associated 
with the Astropy Project, see http://dashboard.astropy.org.

License
-------
Astropy is licensed under a 3-clause BSD style license - see the
``licenses/LICENSE.rst`` file.
